==> POE-Component-IRC-PluginBundle-WebDevelopment-2.001001.tar.gz: POE-Component-IRC-PluginBundle-WebDevelopment-2.001001/README.md <==
# NAME

POE::Component::IRC::Plugin::WebDevelopment - a collection of plugins useful for Web Development IRC bots

# CONTENTS

This distribution provides the following
[POE::Component::IRC](https://metacpan.org/pod/POE::Component::IRC) plugins:

- [POE::Component::IRC::Plugin::AntiSpamMailTo](https://metacpan.org/pod/POE::Component::IRC::Plugin::AntiSpamMailTo) generate `mailto:` links that avoid dumb spam bots
- [POE::Component::IRC::Plugin::BrowserSupport](https://metacpan.org/pod/POE::Component::IRC::Plugin::BrowserSupport) lookup browser support for CSS/HTML/JS
- [POE::Component::IRC::Plugin::CSS::Minifier](https://metacpan.org/pod/POE::Component::IRC::Plugin::CSS::Minifier) "minify" CSS code
- [POE::Component::IRC::Plugin::CSS::PropertyInfo](https://metacpan.org/pod/POE::Component::IRC::Plugin::CSS::PropertyInfo) lookup CSS property information
- [POE::Component::IRC::Plugin::CSS::SelectorTools](https://metacpan.org/pod/POE::Component::IRC::Plugin::CSS::SelectorTools) couple of CSS selector tools
- [POE::Component::IRC::Plugin::HTML::AttributeInfo](https://metacpan.org/pod/POE::Component::IRC::Plugin::HTML::AttributeInfo) HTML attribute info lookup
- [POE::Component::IRC::Plugin::HTML::ElementInfo](https://metacpan.org/pod/POE::Component::IRC::Plugin::HTML::ElementInfo) lookup HTML element information
- [POE::Component::IRC::Plugin::JavaScript::Minifier](https://metacpan.org/pod/POE::Component::IRC::Plugin::JavaScript::Minifier) PoCo::IRC plugin to minify JavaScript code
- [POE::Component::IRC::Plugin::Syntax::Highlight::CSS](https://metacpan.org/pod/POE::Component::IRC::Plugin::Syntax::Highlight::CSS) highlight CSS code from URIs
- [POE::Component::IRC::Plugin::Syntax::Highlight::HTML](https://metacpan.org/pod/POE::Component::IRC::Plugin::Syntax::Highlight::HTML) highlight HTML code from URIs
- [POE::Component::IRC::Plugin::Validator::CSS](https://metacpan.org/pod/POE::Component::IRC::Plugin::Validator::CSS) non-blocking CSS validator
- [POE::Component::IRC::Plugin::Validator::HTML](https://metacpan.org/pod/POE::Component::IRC::Plugin::Validator::HTML) non-blocking HTML validator
- [POE::Component::IRC::Plugin::WWW::Alexa::TrafficRank](https://metacpan.org/pod/POE::Component::IRC::Plugin::WWW::Alexa::TrafficRank) get Alexa traffic rank for pages
- [POE::Component::IRC::Plugin::WWW::DoctypeGrabber](https://metacpan.org/pod/POE::Component::IRC::Plugin::WWW::DoctypeGrabber) plugin to display DOCTYPEs and relevant information from given pages
- [POE::Component::IRC::Plugin::WWW::GetPageTitle](https://metacpan.org/pod/POE::Component::IRC::Plugin::WWW::GetPageTitle) web page title fetching IRC plugin
- [POE::Component::IRC::Plugin::WWW::HTMLTagAttributeCounter](https://metacpan.org/pod/POE::Component::IRC::Plugin::WWW::HTMLTagAttributeCounter) html tag and attribute counter
- [POE::Component::IRC::Plugin::WWW::Lipsum](https://metacpan.org/pod/POE::Component::IRC::Plugin::WWW::Lipsum) plugin to generate Lorem Ipsum text

# EXAMPLES

This distribution contains `examples/` directory, with usage examples
of each plugin.

# REPOSITORY

Fork this module on GitHub:
[https://github.com/zoffixznet/POE-Component-IRC-PluginBundle-WebDevelopment](https://github.com/zoffixznet/POE-Component-IRC-PluginBundle-WebDevelopment)

# BUGS

To report bugs or request features, please use
[https://github.com/zoffixznet/POE-Component-IRC-PluginBundle-WebDevelopment/issues](https://github.com/zoffixznet/POE-Component-IRC-PluginBundle-WebDevelopment/issues)

If you can't access GitHub, you can email your request
to `bug-POE-Component-IRC-PluginBundle-WebDevelopment at rt.cpan.org`

# AUTHOR

Zoffix Znet <zoffix at cpan.org>
([http://zoffix.com/](http://zoffix.com/), [http://haslayout.net/](http://haslayout.net/))

# LICENSE

You can use and distribute this module under the same terms as Perl itself.
See the `LICENSE` file included in this distribution for complete
details.

==> POE-Component-IRC-PluginBundle-WebDevelopment-2.001002.tar.gz: POE-Component-IRC-PluginBundle-WebDevelopment-2.001002/README.md <==
# NAME

POE::Component::IRC::Plugin::WebDevelopment - a collection of plugins useful for Web Development IRC bots

# CONTENTS

This distribution provides the following
[POE::Component::IRC](https://metacpan.org/pod/POE::Component::IRC) plugins:

- [POE::Component::IRC::Plugin::AntiSpamMailTo](https://metacpan.org/pod/POE::Component::IRC::Plugin::AntiSpamMailTo) generate `mailto:` links that avoid dumb spam bots
- [POE::Component::IRC::Plugin::BrowserSupport](https://metacpan.org/pod/POE::Component::IRC::Plugin::BrowserSupport) lookup browser support for CSS/HTML/JS
- [POE::Component::IRC::Plugin::ColorNamer](https://metacpan.org/pod/POE::Component::IRC::Plugin::ColorNamer) tells the name of the color by its hex code
- [POE::Component::IRC::Plugin::CSS::Minifier](https://metacpan.org/pod/POE::Component::IRC::Plugin::CSS::Minifier) "minify" CSS code
- [POE::Component::IRC::Plugin::CSS::PropertyInfo](https://metacpan.org/pod/POE::Component::IRC::Plugin::CSS::PropertyInfo) lookup CSS property information
- [POE::Component::IRC::Plugin::CSS::SelectorTools](https://metacpan.org/pod/POE::Component::IRC::Plugin::CSS::SelectorTools) couple of CSS selector tools
- [POE::Component::IRC::Plugin::Google::PageRank](https://metacpan.org/pod/POE::Component::IRC::Plugin::Google::PageRank) non-blocking access to Google's PageRank via IRC
- [POE::Component::IRC::Plugin::HTML::AttributeInfo](https://metacpan.org/pod/POE::Component::IRC::Plugin::HTML::AttributeInfo) HTML attribute info lookup
- [POE::Component::IRC::Plugin::HTML::ElementInfo](https://metacpan.org/pod/POE::Component::IRC::Plugin::HTML::ElementInfo) lookup HTML element information
- [POE::Component::IRC::Plugin::JavaScript::Minifier](https://metacpan.org/pod/POE::Component::IRC::Plugin::JavaScript::Minifier) PoCo::IRC plugin to minify JavaScript code
- [POE::Component::IRC::Plugin::Syntax::Highlight::CSS](https://metacpan.org/pod/POE::Component::IRC::Plugin::Syntax::Highlight::CSS) highlight CSS code from URIs
- [POE::Component::IRC::Plugin::Syntax::Highlight::HTML](https://metacpan.org/pod/POE::Component::IRC::Plugin::Syntax::Highlight::HTML) highlight HTML code from URIs
- [POE::Component::IRC::Plugin::Validator::CSS](https://metacpan.org/pod/POE::Component::IRC::Plugin::Validator::CSS) non-blocking CSS validator
- [POE::Component::IRC::Plugin::Validator::HTML](https://metacpan.org/pod/POE::Component::IRC::Plugin::Validator::HTML) non-blocking HTML validator
- [POE::Component::IRC::Plugin::WWW::Alexa::TrafficRank](https://metacpan.org/pod/POE::Component::IRC::Plugin::WWW::Alexa::TrafficRank) get Alexa traffic rank for pages
- [POE::Component::IRC::Plugin::WWW::DoctypeGrabber](https://metacpan.org/pod/POE::Component::IRC::Plugin::WWW::DoctypeGrabber) plugin to display DOCTYPEs and relevant information from given pages
- [POE::Component::IRC::Plugin::WWW::GetPageTitle](https://metacpan.org/pod/POE::Component::IRC::Plugin::WWW::GetPageTitle) web page title fetching IRC plugin
- [POE::Component::IRC::Plugin::WWW::HTMLTagAttributeCounter](https://metacpan.org/pod/POE::Component::IRC::Plugin::WWW::HTMLTagAttributeCounter) html tag and attribute counter
- [POE::Component::IRC::Plugin::WWW::Lipsum](https://metacpan.org/pod/POE::Component::IRC::Plugin::WWW::Lipsum) plugin to generate Lorem Ipsum text

# EXAMPLES

This distribution contains `examples/` directory, with usage examples
of each plugin.

# REPOSITORY

Fork this module on GitHub:
[https://github.com/zoffixznet/POE-Component-IRC-PluginBundle-WebDevelopment](https://github.com/zoffixznet/POE-Component-IRC-PluginBundle-WebDevelopment)

# BUGS

To report bugs or request features, please use
[https://github.com/zoffixznet/POE-Component-IRC-PluginBundle-WebDevelopment/issues](https://github.com/zoffixznet/POE-Component-IRC-PluginBundle-WebDevelopment/issues)

If you can't access GitHub, you can email your request
to `bug-POE-Component-IRC-PluginBundle-WebDevelopment at rt.cpan.org`

# AUTHOR

Zoffix Znet <zoffix at cpan.org>
([http://zoffix.com/](http://zoffix.com/), [http://haslayout.net/](http://haslayout.net/))

# LICENSE

You can use and distribute this module under the same terms as Perl itself.
See the `LICENSE` file included in this distribution for complete
details.
